==> sdk-web-components-11.0.1.tgz: package/dist-vite/collection/components/bp-sdk-quote-request-status-list/bp-sdk-quote-request-status-list.js <==
import { h } from "@stencil/core";
export class BpSdkQuoteRequestStatusList {
    constructor() {
        this.isConsumerSelected = undefined;
        this.isExpired = undefined;
        this.isFocused = undefined;
        this.isRecommended = undefined;
        this.isSelected = undefined;
        this.useExternal = false;
    }
    resetState() { }
    componentWillLoad() {
        this.useExternal = !!customElements.get('bp-sdk-external-quote-request-status-list');
        customElements.whenDefined('bp-sdk-external-quote-request-status-list').then(() => {
            this.useExternal = true;
        });
    }
    render() {
        return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
    }
    renderExternal() {
        return (h("bp-sdk-external-quote-request-status-list", { isConsumerSelected: this.isConsumerSelected, isExpired: this.isExpired, isFocused: this.isFocused, isRecommended: this.isRecommended, isSelected: this.isSelected }));
    }
    renderInternal() {
        return (h("div", { class: "bp-sdk-quote-request-status-list__container bp-sdk-online-quote-statuses-container bp-sdk-quote-statuses-container" }, this.isRecommended && h("bp-sdk-chip", { type: "recommended", text: "Recommended" }), this.isSelected && h("bp-sdk-chip", { type: "selected", text: "Selected" }), this.isConsumerSelected && h("bp-sdk-chip", { type: "consumer_selected", text: "Consumer Selected" }), this.isFocused && h("bp-sdk-chip", { type: "focused", text: "Last Viewed" }), this.isExpired && h("bp-sdk-chip", { type: "expired", text: "Expired" })));
    }
    static get is() { return "bp-sdk-quote-request-status-list"; }
    static get originalStyleUrls() {
        return {
            "$": ["./bp-sdk-quote-request-status-list.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["bp-sdk-quote-request-status-list.css"]
        };
    }
    static get properties() {
        return {
            "isConsumerSelected": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "is consumer selected"
                },
                "attribute": "is-consumer-selected",
                "reflect": false
            },
            "isExpired": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Is expired"
                },
                "attribute": "is-expired",
                "reflect": false
            },
            "isFocused": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Is focused"
                },
                "attribute": "is-focused",
                "reflect": false
            },
            "isRecommended": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Is recommended"
                },
                "attribute": "is-recommended",
                "reflect": false
            },
            "isSelected": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Is selected"
                },
                "attribute": "is-selected",
                "reflect": false
            }
        };
    }
    static get states() {
        return {
            "useExternal": {}
        };
    }
}

==> sdk-web-components-12.0.0.tgz: package/dist-vite/collection/components/bp-sdk-quote-request-status-list/bp-sdk-quote-request-status-list.js <==
import { h } from "@stencil/core";
export class BpSdkQuoteRequestStatusList {
    constructor() {
        this.isConsumerSelected = undefined;
        this.isExpired = undefined;
        this.isFocused = undefined;
        this.isRecommended = undefined;
        this.isSelected = undefined;
        this.useExternal = false;
    }
    resetState() { }
    componentWillLoad() {
        this.useExternal = !!customElements.get('bp-sdk-external-quote-request-status-list');
        customElements
            .whenDefined('bp-sdk-external-quote-request-status-list')
            .then(() => {
            this.useExternal = true;
        });
    }
    render() {
        return [
            this.useExternal && this.renderExternal(),
            !this.useExternal && this.renderInternal(),
        ];
    }
    renderExternal() {
        return (h("bp-sdk-external-quote-request-status-list", { isConsumerSelected: this.isConsumerSelected, isExpired: this.isExpired, isFocused: this.isFocused, isRecommended: this.isRecommended, isSelected: this.isSelected }));
    }
    renderInternal() {
        return (h("div", { class: "bp-sdk-quote-request-status-list__container bp-sdk-online-quote-statuses-container bp-sdk-quote-statuses-container" }, this.isRecommended && (h("bp-sdk-chip", { type: "recommended", text: "Recommended" })), this.isSelected && (h("bp-sdk-chip", { type: "selected", text: "Selected" })), this.isConsumerSelected && (h("bp-sdk-chip", { type: "consumer_selected", text: "Consumer Selected" })), this.isFocused && (h("bp-sdk-chip", { type: "focused", text: "Last Viewed" })), this.isExpired && (h("bp-sdk-chip", { type: "expired", text: "Expired" }))));
    }
    static get is() { return "bp-sdk-quote-request-status-list"; }
    static get originalStyleUrls() {
        return {
            "$": ["./bp-sdk-quote-request-status-list.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["bp-sdk-quote-request-status-list.css"]
        };
    }
    static get properties() {
        return {
            "isConsumerSelected": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "is consumer selected"
                },
                "attribute": "is-consumer-selected",
                "reflect": false
            },
            "isExpired": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Is expired"
                },
                "attribute": "is-expired",
                "reflect": false
            },
            "isFocused": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Is focused"
                },
                "attribute": "is-focused",
                "reflect": false
            },
            "isRecommended": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Is recommended"
                },
                "attribute": "is-recommended",
                "reflect": false
            },
            "isSelected": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Is selected"
                },
                "attribute": "is-selected",
                "reflect": false
            }
        };
    }
    static get states() {
        return {
            "useExternal": {}
        };
    }
}
